UnixListener

Struct UnixListener 

pub struct UnixListener { /* private fields */ }
A Unix socket server, listening for connections.

You can accept a new connection by using the UnixListener::accept method.

Examples

use compio_io::{AsyncReadExt, AsyncWriteExt};
use compio_net::{UnixListener, UnixStream};
use tempfile::tempdir;

let dir = tempdir().unwrap();
let sock_file = dir.path().join("unix-server.sock");

let listener = UnixListener::bind(&sock_file).await.unwrap();

let (mut tx, (mut rx, _)) =
    futures_util::try_join!(UnixStream::connect(&sock_file), listener.accept()).unwrap();

tx.write_all("test").await.0.unwrap();

let (_, buf) = rx.read_exact(Vec::with_capacity(4)).await.unwrap();

assert_eq!(buf, b"test");

Implementations

Source

impl UnixListener

pub async fn bind(path: impl AsRef<Path>) -> Result<UnixListener, Error>

Creates a new UnixListener, which will be bound to the specified file path. The file path cannot yet exist, and will be cleaned up upon dropping UnixListener

pub async fn bind_addr(addr: &SockAddr) -> Result<UnixListener, Error>

Creates a new UnixListener with SockAddr, which will be bound to the specified file path. The file path cannot yet exist, and will be cleaned up upon dropping UnixListener

pub fn close(self) -> impl Future<Output = Result<(), Error>>

Close the socket. If the returned future is dropped before polling, the socket won’t be closed.

pub async fn accept(&self) -> Result<(UnixStream, SockAddr), Error>

Accepts a new incoming connection from this listener.

This function will yield once a new Unix domain socket connection is established. When established, the corresponding UnixStream and will be returned.

pub fn local_addr(&self) -> Result<SockAddr, Error>

Returns the local address that this listener is bound to.