pub type SocketMonitor = Receiver<SocketEvent>;Expand description
Handle for receiving socket events.
This is a channel receiver that provides a stream of socket lifecycle events.
Aliased Type
pub struct SocketMonitor { /* private fields */ }pub type SocketMonitor = Receiver<SocketEvent>;Handle for receiving socket events.
This is a channel receiver that provides a stream of socket lifecycle events.
pub struct SocketMonitor { /* private fields */ }